/* -*- Mode:C++; c-file-style:"gnu"; indent-tabs-mode:nil; -*- */
/*
 * Copyright (c) 2008 INRIA
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2 as
 * published by the Free Software Foundation;
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Authors: Mathieu Lacage <mathieu.lacage@sophia.inria.fr>
 */
#include "trace-source-accessor.h"
#include "log.h"

/**
 * \file
 * \ingroup tracing
 * ns3::TraceSourceAccessor implementation (constructor and destructor).
 */

namespace ns3 {

NS_LOG_COMPONENT_DEFINE ("TraceSourceAccessor");

TraceSourceAccessor::TraceSourceAccessor ()
{
}
TraceSourceAccessor::~TraceSourceAccessor ()
{
}

} // namespace ns3
